@@ -9,6 +9,7 @@ use English; use Exporter; use DynaLoader;
 @ISA    = qw( Exporter DynaLoader ); 
 
 @EXPORT = qw(genpp %PDL_DATATYPES PDL_INCLUDE PDL_TYPEMAP
+		 PDL_INST_INCLUDE PDL_INST_TYPEMAP
 		 pdlpp_postamble_int pdlpp_stdargs_int
 		 pdlpp_postamble pdlpp_stdargs
 		 );
@@ -16,8 +17,15 @@ use English; use Exporter; use DynaLoader;
 # Installation locations
 # beware: whereami_any now appends the /Basic or /PDL directory as appropriate
 
+# The INST are here still just in case we want to change something later.
+
 sub PDL_INCLUDE { '-I'.whereami_any().'/Core' };
 sub PDL_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
+sub PDL_INST_INCLUDE { '-I'.whereami_any().'/Core' };
+sub PDL_INST_TYPEMAP { whereami_any().'/Core/typemap.pdl' };
+
+sub PDL_INST_INCLUDE {&PDL_INCLUDE}
+sub PDL_INST_TYPEMAP {&PDL_TYPEMAP}
 
 # Data types to C types mapping
 # get the map from Types.pm
@@ -258,15 +266,16 @@ sub pdlpp_stdargs_int {
  my($src,$pref,$mod) = @$rec;
  my $w = whereami();
  return (
+ 	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
 	 'VERSION_FROM' => "$w/Basic/Core/Version.pm",
 	 'TYPEMAPS'     => [&PDL_TYPEMAP()], 
 	 'OBJECT'       => "$pref\$(OBJ_EXT)",           
 	 PM 	=> {"$pref.pm" => "\$(INST_LIBDIR)/$pref.pm"},
-	 MAN3PODS => {"$src" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
+	 MAN3PODS => {"$pref.pm" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
 	 'INC'          => &PDL_INCLUDE(),
 	 'LIBS'         => [''],
-	 'clean'        => {'FILES'  => "$pref.xs $pref.pm"},
+	 'clean'        => {'FILES'  => "$pref.xs $pref.pm $pref\$(OBJ_EXT) $pref.c"},
  );
 }
 
@@ -274,14 +283,15 @@ sub pdlpp_stdargs {
  my($rec) = @_;
  my($src,$pref,$mod) = @$rec;
  return (
+ 	%::PDL_OPTIONS,
 	 'NAME'  	=> $mod,
 	 'TYPEMAPS'     => [&PDL_INST_TYPEMAP()], 
 	 'OBJECT'       => "$pref\$(OBJ_EXT)",           
 	 PM 	=> {"$pref.pm" => "\$(INST_LIBDIR)/$pref.pm"},
-	 MAN3PODS => {"$src" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
+	 MAN3PODS => {"$pref.pm" => "\$(INST_MAN3DIR)/$mod.\$(MAN3EXT)"},
 	 'INC'          => &PDL_INST_INCLUDE(),
 	 'LIBS'         => [''],
-	 'clean'        => {'FILES'  => "$pref.xs $pref.pm"},
+	 'clean'        => {'FILES'  => "$pref.xs $pref.pm $pref\$(OBJ_EXT) $pref.c"},
  );
 }
 
